<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans https://git.spip.net/spip/bigup.git

return [

	// B
	'bigup_description' => 'Téléverser les documents par glisser-déposer',
	'bigup_nom' => 'Big Upload',
	'bigup_slogan' => 'Téléverser des fichiers, quelque soit leur taille',
];
